@@ -3,6 +3,7 @@ import time
 import ssl
 import pkg_resources
 import google.protobuf.text_format
+import google.protobuf.json_format
 from . import abi
 from . import casper_pb2 as casper
 from . import consensus_pb2 as consensus
@@ -21,6 +22,10 @@ def hexify(o):
     return google.protobuf.text_format.MessageToString(o)
 
 
+def jsonify(o):
+    return google.protobuf.json_format.MessageToJson(o)
+
+
 def bundled_contract(file_name):
     """
     Return path to contract file bundled with the package.
